@@ -110,10 +110,7 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
             if (cookieStore.getCookies().size() == 0) {
                 throw ApiFacadeException.internalServerError("No cookies received.");
             }
-            SessionData sessionData = new SessionData(responseBody.getSession(), cookieStore.getCookies());
-            sessionData.setProperty(SessionData.PROPERTY_CONTEXT_ID, Long.toString(responseBody.getContextId()));
-            sessionData.setProperty(SessionData.PROPERTY_USER_ID, Long.toString(responseBody.getUserId()));
-            return sessionData;
+            return new SessionData(responseBody.getSession(), cookieStore.getCookies());
         } catch (Exception e) {
             if (e instanceof ConnectTimeoutException) {
                 throw ApiFacadeException.gatewayTimeoutError(e);
@@ -141,10 +138,6 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
         if (userAgent != null) {
             builder.addHeader(RequestUtil.HEADER_USER_AGENT, userAgent);
         }
-        String trackingId = credentials.getTrackingId();
-        if (trackingId != null) {
-            builder.addParameter("trackingId", trackingId);
-        }
         return builder
                 .addParameter("action", "login")
                 .addParameter("name", credentials.getUsername())
