@@ -53,7 +53,7 @@ import java.net.URI;
 import java.net.URISyntaxException;
 
 import com.openexchange.config.ConfigurationService;
-import com.openexchange.mobile.api.facade.utils.StringUtils;
+import com.openexchange.java.Strings;
 
 import lombok.experimental.UtilityClass;
 import lombok.extern.slf4j.Slf4j;
@@ -82,7 +82,7 @@ public class GlobalConfiguration {
     private void validate() {
         if (middlewareBaseUrl == null) {
             log.error("property \"" + MIDDLEWARE_BASE_URL + "\" not set");
-        } else if (StringUtils.isEmpty(middlewareBaseUrl.getHost())) {
+        } else if (Strings.isEmpty(middlewareBaseUrl.getHost())) {
             log.error("hostname cannot get extracted from property \"" + MIDDLEWARE_BASE_URL + "\"");
         }
     }
@@ -90,7 +90,7 @@ public class GlobalConfiguration {
     private URI getMiddlewareBaseUrl(ConfigurationService configurationService) {
         try {
             String value = ConfigurationHelper.getStringOrNull(configurationService, MIDDLEWARE_BASE_URL);
-            if (StringUtils.isEmpty(value)) {
+            if (Strings.isEmpty(value)) {
                 return null;
             }
             if (!value.endsWith("/")) {
