@@ -49,7 +49,6 @@
 
 package com.openexchange.mobile.api.facade.configuration;
 
-import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.List;
 import java.util.Map;
@@ -80,7 +79,7 @@ public class HostConfiguration {
 
     /*private*/ static final String MAILS_PER_FOLDER = "com.openexchange.mobile.api.facade.numMailsPerFolder";
 
-    /*private*/ public static final String RETURN_NON_PRIMARY_ACCOUNTS = "com.openexchange.mobile.api.facade.returnNonPrimaryAccounts";
+    /*private*/ static final String RETURN_NON_PRIMARY_ACCOUNTS = "com.openexchange.mobile.api.facade.returnNonPrimaryAccounts";
 
     /*private*/ static final String INCLUDE_NON_PRIVATE_FOLDERS = "com.openexchange.mobile.api.facade.includeNonPrivateFolders";
 
@@ -108,14 +107,10 @@ public class HostConfiguration {
 
     /*private*/ public static final String FORWARD_HOST_HEADER = "com.openexchange.mobile.api.facade.forwardHostHeader";
 
-    /*private*/ public static final String CUSTOM_PROPERTIES = "customProperties";
-
     String authenticationClassName;
 
     Map<String, String> minimumClientVersions = new Hashtable<>();
 
-    Map<String, String> customProperties = new HashMap<>();
-
     ThreadingType threadingType;
 
     String numMailsPerFolder;
@@ -263,14 +258,6 @@ public class HostConfiguration {
                 }
                 continue;
 
-            case CUSTOM_PROPERTIES:
-                @SuppressWarnings("unchecked")
-                Map<String, Object> map = (Map<String, Object>) propertyValue;
-                for (Map.Entry<String, Object> customPropertyEntry : map.entrySet()) {
-                    customProperties.put(customPropertyEntry.getKey(), customPropertyEntry.getValue().toString());
-                }
-                continue;
-
             default:
                 log.warn("Unrecognized configuration property '" + propertyName + "'");
                 continue;
