@@ -55,14 +55,15 @@ import java.io.IOException;
 import com.fasterxml.jackson.databind.JavaType;
 import com.fasterxml.jackson.databind.JsonMappingException;
 import com.fasterxml.jackson.databind.ObjectMapper;
+import com.openexchange.java.Strings;
 import com.openexchange.mobile.api.facade.auth.SessionData;
+import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
 import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
 import com.openexchange.mobile.api.facade.utils.JacksonUtil;
 import com.openexchange.mobile.api.facade.utils.RequestUtil;
 
 import lombok.extern.slf4j.Slf4j;
 
-import org.apache.commons.lang.StringUtils;
 import org.apache.http.HttpEntity;
 import org.apache.http.HttpResponse;
 import org.apache.http.StatusLine;
@@ -71,6 +72,7 @@ import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.client.methods.HttpUriRequest;
 import org.apache.http.client.methods.RequestBuilder;
 import org.apache.http.client.protocol.HttpClientContext;
+import org.apache.http.conn.ConnectTimeoutException;
 import org.apache.http.cookie.Cookie;
 import org.apache.http.entity.BufferedHttpEntity;
 import org.apache.http.impl.client.CloseableHttpClient;
@@ -98,12 +100,19 @@ public abstract class AbstractConnector<T> implements Connector<T, T> {
     protected abstract HttpUriRequest createRequest();
 
     protected void addSessionData(RequestBuilder builder) {
+        HostConfiguration configuration = sessionData.getConfiguration();
+        if (configuration.isForwardHostHeader()) {
+            String hostname = sessionData.getHost();
+            if (!Strings.isEmpty(hostname)) {
+                builder.addHeader(RequestUtil.HEADER_HOST, hostname);
+            }
+        }
         String forwardedFor = sessionData.getForwardedFor();
-        if (!StringUtils.isEmpty(forwardedFor)) {
+        if (!Strings.isEmpty(forwardedFor)) {
             builder.addHeader(RequestUtil.HEADER_X_FORWARDED_FOR, forwardedFor);
         }
         String userAgent = sessionData.getUserAgent();
-        if (!StringUtils.isEmpty(userAgent)) {
+        if (!Strings.isEmpty(userAgent)) {
             builder.addHeader(RequestUtil.HEADER_USER_AGENT, userAgent);
         }
         builder.addParameter("session", sessionData.getSession());
@@ -130,6 +139,9 @@ public abstract class AbstractConnector<T> implements Connector<T, T> {
             return handleResponse(response);
         } catch (Exception e) {
             log.error("Failed to execute request", e);
+            if (e instanceof ConnectTimeoutException) {
+                throw ApiFacadeException.gatewayTimeoutError(e);
+            }
             throw ApiFacadeException.internalServerError(e);
         }
     }
