@@ -71,7 +71,6 @@ public class AccountCto {
     @NonNull
     private final String accountName;
 
-
     private final String userName;
 
     private final String firstName;
@@ -107,16 +106,21 @@ public class AccountCto {
         primaryAddress = account.getPrimaryAddress();
         aliases = ListUtil.map(account.getAliases(), aliasesMapFunction);
         canSend = account.isCanSend();
-        /* Java8: Use with Java 8.
-        folders = account.getFolders().stream()
-                .map(folder -> new FolderCto(folder))
-                .collect(Collectors.toList());
-        */
-        folders = new ArrayList<>();
-        for (Folder folder : account.getFolders()) {
-            folders.add(new FolderCto(folder));
+        if (account.getFolders() != null) {
+            /* Java8: Use with Java 8.
+            folders = account.getFolders().stream()
+                    .map(folder -> new FolderCto(folder))
+                    .collect(Collectors.toList());
+            */
+            folders = new ArrayList<>();
+            for (Folder folder : account.getFolders()) {
+                folders.add(new FolderCto(folder));
+            }
+            standardFolders = new StandardFoldersCto(account.getStandardFolders());
+        } else {
+            folders = null;
+            standardFolders = null;
         }
-        standardFolders = new StandardFoldersCto(account.getStandardFolders());
     }
 
 }
