@@ -49,9 +49,6 @@
 
 package com.openexchange.mobile.api.facade.exceptions;
 
-import java.util.Collections;
-import java.util.List;
-
 import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.Status;
@@ -84,16 +81,6 @@ public class ApiFacadeException extends WebApplicationException {
 
         int EMPTY_ARRAY_NOT_ALLOWED = 8;
 
-        int INVALID_ACCOUNT_DATA = 9;
-
-        int REDIRECT = 10;
-
-        int SERVICE_UNAVAILABLE = 11;
-
-        int PASSWORD_OF_SECONDARY_MAIL_ACCOUNT_CHANGED = 12;
-
-        int PERMISSION_DENIED = 13;
-
         String INVALID_SESSION = "SES-206";
 
         int CLIENT_UPDATE_MANDATORY = 900;
@@ -119,28 +106,8 @@ public class ApiFacadeException extends WebApplicationException {
             return invalidSession();
         } else if (areCredentialsInvalid(code)) {
             return invalidCredentials();
-        } else if (isDatabaseUpdate(code)) {
-            return serviceUnavailable();
-        } else if (isPasswordOfSecondaryAccountChanged(code)) {
-            return passwordSecondaryAccountChanged();
-        } else if (isPermissionDenied(code)) {
-            return permissionDenied(error);
-        } else if (isRedirect(code)) {
-            return redirect(error);
-        }
-        List<String> categories = getCategories(responseBody.getCategories());
-        return create(Status.BAD_REQUEST, code, null, responseBody.getError(), categories);
-    }
-
-    @SuppressWarnings("unchecked")
-    private static List<String> getCategories(Object categories) {
-        if (categories instanceof String) {
-            return Collections.<String>singletonList((String) categories);
-        } else if (categories instanceof List) {
-            return (List<String>) categories;
-        } else {
-            return null;
         }
+        return create(Status.BAD_REQUEST, code, responseBody.getErrorDescription());
     }
 
     private static boolean isMaximumNumberOfSessionsExceeded(String code) {
@@ -156,22 +123,6 @@ public class ApiFacadeException extends WebApplicationException {
         return "MSG-1000".equals(code) || "LGI-0006".equals(code);
     }
 
-    private static boolean isDatabaseUpdate(String code) {
-        return "CTX-0007".equals(code);
-    }
-
-    private static boolean isPasswordOfSecondaryAccountChanged(String code) {
-        return "MSG-1016".equals(code);
-    }
-
-    private static boolean isPermissionDenied(String code) {
-        return "LGI-0013".equals(code);
-    }
-
-    private static boolean isRedirect(String code) {
-        return "LGI-0016".equals(code);
-    }
-
     public static ApiFacadeException badRequest(int errorCode, String message) {
         return create(Status.BAD_REQUEST, errorCode, message);
     }
@@ -188,10 +139,6 @@ public class ApiFacadeException extends WebApplicationException {
         return create(Status.UNAUTHORIZED, Code.INVALID_SESSION, "Your session was invalidated. Please try again.");
     }
 
-    public static ApiFacadeException redirect(String location) {
-        return create(Status.TEMPORARY_REDIRECT, Code.REDIRECT, location);
-    }
-
     public static ApiFacadeException missingHeader(String name) {
         return create(Status.BAD_REQUEST, Code.MISSING_HEADER, "Header missing: " + name);
     }
@@ -241,15 +188,15 @@ public class ApiFacadeException extends WebApplicationException {
     }
 
     private static ApiFacadeException create(Status status, int errorCode, Exception cause, String message) {
-        return create(status, String.valueOf(errorCode), cause, message, null);
+        return create(status, String.valueOf(errorCode), cause, message);
     }
 
     private static ApiFacadeException create(Status status, String errorCode, String message) {
-        return create(status, errorCode, null, message, null);
+        return create(status, errorCode, null, message);
     }
 
-    private static ApiFacadeException create(Status status, String errorCode, Exception cause, String message, List<String> categories) {
-        String responseBody = JacksonUtil.toString(new AbstractResponseBody(errorCode, message, categories));
+    private static ApiFacadeException create(Status status, String errorCode, Exception cause, String message) {
+        String responseBody = JacksonUtil.toString(new AbstractResponseBody(errorCode, message));
         Response response = Response.status(status).entity(responseBody).build();
         return new ApiFacadeException(errorCode, cause, message, response);
     }
@@ -262,20 +209,4 @@ public class ApiFacadeException extends WebApplicationException {
         return create(Status.NOT_FOUND, Code.ACCOUNT_NOT_FOUND, "Account not found: " + accountId);
     }
 
-    public static ApiFacadeException invalidAccountData() {
-        return create(Status.BAD_REQUEST, Code.INVALID_ACCOUNT_DATA, "Invalid account data");
-    }
-
-    public static ApiFacadeException serviceUnavailable() {
-        return create(Status.SERVICE_UNAVAILABLE, Code.SERVICE_UNAVAILABLE, "Service unavailable");
-    }
-
-    public static ApiFacadeException passwordSecondaryAccountChanged() {
-        return create(Status.SERVICE_UNAVAILABLE, Code.PASSWORD_OF_SECONDARY_MAIL_ACCOUNT_CHANGED, "Password of secondary mail account changed");
-    }
-
-    public static ApiFacadeException permissionDenied(String errorMessage) {
-        return create(Status.FORBIDDEN, Code.PERMISSION_DENIED, errorMessage != null ? errorMessage : "Permission denied");
-    }
-
 }
