@@ -49,6 +49,7 @@
 
 package com.openexchange.mobile.api.facade.services;
 
+import java.util.ArrayList;
 import java.util.List;
 
 import com.openexchange.mobile.api.facade.auth.SessionData;
@@ -90,7 +91,11 @@ public class ConfigService {
     private List<Capability> retrieveCapabilities(ConnectorFactory connectorFactory, SessionData sessionData) {
         AllCapabilitiesConnector connector = connectorFactory.getAllCapabilities(sessionData);
         CapabilitiesResponseMto response = connector.execute();
-        return AllCapabilitiesConnector.map(response);
+        List<Capability> remoteCapabilities = AllCapabilitiesConnector.map(response);
+        List<Capability> capabilities = new ArrayList<>(remoteCapabilities.size() + 1);
+        capabilities.addAll(remoteCapabilities);
+        capabilities.add(new Capability("facade_accounts_sync"));
+        return capabilities;
     }
 
 }
