@@ -58,7 +58,7 @@ import lombok.experimental.UtilityClass;
 @UtilityClass
 public class AttachmentUtil {
 
-    public void initializeDownloadUrls(String sessionToken, String folderId, Mail mail) {
+    public void initializeDownloadUrls(String folderId, Mail mail) {
         if (mail == null || mail.getParts() == null) {
             return;
         }
@@ -66,14 +66,14 @@ public class AttachmentUtil {
             Boolean isTruncated = attachment.getTruncated();
             if (Disposition.ATTACHMENT.equals(attachment.getDisposition())
                     || (isTruncated != null && isTruncated)) {
-                String downloadUrl = buildDownloadUrl(sessionToken, folderId, mail, attachment);
+                String downloadUrl = buildDownloadUrl(folderId, mail, attachment);
                 attachment.setDownloadUrl(downloadUrl);
             }
         }
     }
 
-    private String buildDownloadUrl(String sessionToken, String folderId, Mail mail, Attachment attachment) {
-        return String.format("/appsuite/api/mail?action=attachment&session=%s&folder=%s&id=%s&attachment=%s", sessionToken, folderId, mail.getId(), attachment.getId());
+    private String buildDownloadUrl(String folderId, Mail mail, Attachment attachment) {
+        return String.format("/appsuite/api/mail?action=attachment&folder=%s&id=%s&attachment=%s", folderId, mail.getId(), attachment.getId());
     }
 
 }
