@@ -61,6 +61,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.ResponseBuilder;
 
+import com.openexchange.java.Strings;
 import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.configuration.ConfigurationHelper;
 import com.openexchange.mobile.api.facade.configuration.GlobalConfiguration;
@@ -73,6 +74,7 @@ import com.vdurmont.semver4j.Semver.SemverType;
 import lombok.SneakyThrows;
 import lombok.experimental.UtilityClass;
 
+import org.apache.http.client.config.RequestConfig;
 import org.apache.http.conn.ssl.NoopHostnameVerifier;
 import org.apache.http.conn.ssl.TrustStrategy;
 import org.apache.http.cookie.Cookie;
@@ -105,9 +107,9 @@ public class RequestUtil {
 
     public static final String HEADER_X_FORWARDED_FOR = "X-Forwarded-For";
 
-    public static final String HEADER_HOST = "HOST";
+    public static final String HEADER_HOST = "Host";
 
-    public static final String HEADER_X_HOST = "X-HOST";
+    public static final String HEADER_X_HOST = "X-Host";
 
     private static final int USER_AGENT_MAXLEN = 100;
 
@@ -116,6 +118,9 @@ public class RequestUtil {
     @SneakyThrows
     public RequestConfiguration createConfiguration() {
         BasicCookieStore cookieStore = new BasicCookieStore();
+        RequestConfig requestConfig = RequestConfig.custom()
+                .setConnectTimeout(10000)
+                .build();
         /* Java8: For Java 8:
         SSLContext sslContext = new SSLContextBuilder()
                 .loadTrustMaterial(null, (TrustStrategy) (chain, authType) -> true)
@@ -131,6 +136,7 @@ public class RequestUtil {
                 .build();
         CloseableHttpClient httpClient = HttpClients.custom()
                 .setDefaultCookieStore(cookieStore)
+                .setDefaultRequestConfig(requestConfig)
                 .setSSLHostnameVerifier(NoopHostnameVerifier.INSTANCE)
                 .setSSLContext(sslContext)
                 .build();
@@ -139,21 +145,23 @@ public class RequestUtil {
 
     public SessionData getSessionData(HttpServletRequest request) {
         String session = request.getHeader(HEADER_SESSION);
-        if (StringUtils.isEmpty(session)) {
+        if (Strings.isEmpty(session)) {
             throw ApiFacadeException.missingHeader(HEADER_SESSION);
         }
         List<Cookie> cookies = getCookies(request, GlobalConfiguration.middlewareBaseUrl.getHost());
         if (cookies.size() == 0) {
             throw ApiFacadeException.badRequest(ApiFacadeException.Code.MISSING_COOKIES, "Cookies missing");
         }
+        String hostname = RequestUtil.getHostHeader(request);
         String userAgent = getUserAgent(request);
         HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(request);
         checkUserAgent(userAgent, hostConfiguration);
-        return enhanceSessionData(request, hostConfiguration, userAgent, new SessionData(session, cookies));
+        return enhanceSessionData(request, hostConfiguration, hostname, userAgent, new SessionData(session, cookies));
     }
 
-    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String userAgent, SessionData sessionData) {
+    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String hostname, String userAgent, SessionData sessionData) {
         return sessionData
+                .withHost(hostname)
                 .withForwardedFor(getForwardedForWithRemoteIp(request))
                 .withUserAgent(userAgent)
                 .withConfiguration(configuration);
@@ -168,10 +176,13 @@ public class RequestUtil {
     }
 
     public void checkUserAgent(String userAgent, HostConfiguration hostConfiguration) {
-        if (StringUtils.isEmpty(userAgent)) {
+        if (Strings.isEmpty(userAgent)) {
             throw ApiFacadeException.missingHeader(HEADER_USER_AGENT);
         }
         UserAgentInfo userAgentInfo = parseUserAgent(userAgent);
+        if (!hostConfiguration.isAllowedBrand(userAgentInfo.getBrand())) {
+            throw ApiFacadeException.forbidden();
+        }
         if (!minimumClientVersionSatisfied(userAgentInfo, hostConfiguration.getMinimumClientVersions())) {
             throw ApiFacadeException.clientUpdateMandatory();
         }
@@ -180,10 +191,10 @@ public class RequestUtil {
     public boolean minimumClientVersionSatisfied(UserAgentInfo userAgentInfo, Map<String, String> minimumClientVersions) {
         String clientVersionStr = userAgentInfo.getVersion();
         String minimumClientVersionStr = getMinimumClientVersion(minimumClientVersions, userAgentInfo);
-        if (StringUtils.isEmpty(minimumClientVersionStr)) {
+        if (Strings.isEmpty(minimumClientVersionStr)) {
             return true;
         }
-        if (StringUtils.isEmpty(clientVersionStr)) {
+        if (Strings.isEmpty(clientVersionStr)) {
             return false;
         }
         Semver clientVersion = new Semver(clientVersionStr, SemverType.LOOSE);
@@ -287,13 +298,22 @@ public class RequestUtil {
         }
     }
 
+    public void checkParam(String name, List<String> values) {
+        if (values == null) {
+            throw ApiFacadeException.missingParameter(name);
+        }
+        if (values.size() == 0) {
+            throw ApiFacadeException.emptyArrayNotAllowed(name);
+        }
+    }
+
     public void checkParam(String name, Object value) {
         if (value == null) {
             throw ApiFacadeException.missingParameter(name);
         }
     }
 
-    public static boolean getBooleanParameter(Boolean currentValue, boolean defaultValue) {
+    public boolean getBooleanParameter(Boolean currentValue, boolean defaultValue) {
         return currentValue == null ? defaultValue : currentValue.booleanValue();
     }
 
