@@ -60,8 +60,4 @@ public class UserAgentInfo {
 
     String version;
 
-    String osVersion;
-
-    String device;
-
 }
